@@ -133,7 +133,7 @@ def cleanup_timeout_tasks(channel: grpc.Channel):
                 "TIMEOUT {desc}".format(desc=task['desc']))
             try:
                 tasks_stub.Kill(tasks_pb2.KillRequest(
-                    container_id=task['container_id'], exec_id=exec_id),  metadata=METADATA)
+                    container_id=task['container_id'], exec_id=exec_id, signal=9, all=True),  metadata=METADATA)
             except:
                 logging.getLogger('cron').error(
                     "KILL FAILED {desc}".format(desc=task['desc']))
